/*	$Id: lib.h 2007/08/21 18:19:56 mallet $ */

/*
 * Copyright (c) 2000-2007 LAAS/CNRS                  --  Wed May 10 2000
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#ifndef _LIBINSITU_H
#define _LIBINSITU_H

#include "t3d/t3d.h"

typedef struct InsituModel *InsituModelId;

typedef struct InsituLinkId *InsituLinkId;
typedef struct InsituPvFrame *InsituFrameId;

typedef enum InsituAccesMode {
   ISMODE_READONLY,
   ISMODE_READWRITE,		/* enable dynamic link modification */
   ISMODE_EDIT			/* enable static link modification */
} InsituAccesMode;


/* Exported frames */

#define ISFRM_MAX_LEN	32

typedef struct InsituFrame {
   char name[ISFRM_MAX_LEN];
   T3D frameToMain;
} InsituFrame;

typedef struct InsituFrameSet {
   int n;			/* number of frames */
   int pad;
   InsituFrame *frame;	/* not at tab anylonger, but a pointer to be allocated */
} InsituFrameSet;



/* Prototypes -------------------------------------------------------- */

InsituModelId	insituOpen(char *geomFile, InsituAccesMode mode);
InsituLinkId	insituOpenLink(InsituModelId id, char *from, char *to);
InsituFrameId	insituOpenFrame(InsituModelId id, char *frame);
int		insituWrite(InsituModelId id, char *file);
void		insituClose(InsituModelId id);

int	insituUpdate(InsituModelId id);

size_t	insituGetExportSize(InsituModelId id);
int	insituExport(InsituModelId id, InsituFrameSet *set);

int	insituSet(InsituLinkId link, T3D *t3d);
int	insituGet(InsituFrameId frame, T3D *t3d);

#endif /* _LIBINSITU_H */
